@@ -5,12 +5,14 @@ from decimal import Decimal
 from functools import wraps
 from typing import TYPE_CHECKING, Any, Callable, Literal, TypeVar, overload
 
+from narwhals._constants import EPOCH, MS_PER_SECOND
 from narwhals._namespace import (
     is_native_arrow,
     is_native_pandas_like,
     is_native_polars,
     is_native_spark_like,
 )
+from narwhals._utils import Version
 from narwhals.dependencies import (
     get_dask,
     get_dask_expr,
@@ -27,7 +29,6 @@ from narwhals.dependencies import (
     is_pyarrow_scalar,
     is_pyarrow_table,
 )
-from narwhals.utils import Version
 
 if TYPE_CHECKING:
     from narwhals.dataframe import DataFrame, LazyFrame
@@ -96,9 +97,9 @@ def to_native(
     Returns:
         Object of class that user started with.
     """
+    from narwhals._utils import validate_strict_and_pass_though
     from narwhals.dataframe import BaseFrame
     from narwhals.series import Series
-    from narwhals.utils import validate_strict_and_pass_though
 
     pass_through = validate_strict_and_pass_though(
         strict, pass_through, pass_through_default=False, emit_deprecation_warning=True
@@ -324,7 +325,7 @@ def from_native(  # noqa: D417
         DataFrame, LazyFrame, Series, or original object, depending
             on which combination of parameters was passed.
     """
-    from narwhals.utils import validate_strict_and_pass_though
+    from narwhals._utils import validate_strict_and_pass_though
 
     pass_through = validate_strict_and_pass_though(
         strict, pass_through, pass_through_default=False, emit_deprecation_warning=True
@@ -355,15 +356,15 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
     allow_series: bool | None = None,
     version: Version,
 ) -> Any:
-    from narwhals.dataframe import DataFrame, LazyFrame
-    from narwhals.series import Series
-    from narwhals.utils import (
+    from narwhals._utils import (
         _supports_dataframe_interchange,
         is_compliant_dataframe,
         is_compliant_lazyframe,
         is_compliant_series,
         parse_version,
     )
+    from narwhals.dataframe import DataFrame, LazyFrame
+    from narwhals.series import Series
 
     # Early returns
     if isinstance(native_object, (DataFrame, LazyFrame)) and not series_only:
@@ -610,7 +611,7 @@ def _get_native_namespace_single_obj(
 ) -> Any:
     from contextlib import suppress
 
-    from narwhals.utils import has_native_namespace
+    from narwhals._utils import has_native_namespace
 
     with suppress(TypeError, AssertionError):
         return Version.MAIN.namespace.from_native_object(
@@ -689,7 +690,7 @@ def narwhalify(
         ... def agnostic_group_by_sum(df):
         ...     return df.group_by("a").agg(nw.col("b").sum())
     """
-    from narwhals.utils import validate_strict_and_pass_though
+    from narwhals._utils import validate_strict_and_pass_though
 
     pass_through = validate_strict_and_pass_though(
         strict, pass_through, pass_through_default=True, emit_deprecation_warning=True
@@ -777,8 +778,8 @@ def to_py_scalar(scalar_like: Any) -> Any:
         and isinstance(scalar_like, np.datetime64)
         and scalar_like.dtype == "datetime64[ns]"
     ):
-        ms = scalar_like.item() // 1000
-        scalar = dt.datetime(1970, 1, 1) + dt.timedelta(microseconds=ms)
+        ms = scalar_like.item() // MS_PER_SECOND
+        scalar = EPOCH + dt.timedelta(microseconds=ms)
     elif is_numpy_scalar(scalar_like) or is_cupy_scalar(scalar_like):
         scalar = scalar_like.item()
     elif pd and isinstance(scalar_like, pd.Timestamp):
