@@ -2,14 +2,16 @@ from __future__ import annotations
 
 from contextlib import nullcontext as does_not_raise
 from datetime import datetime, timezone
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Literal
 
 import pyarrow as pa
 import pytest
 
 import narwhals as nw
 from narwhals._arrow.utils import parse_datetime_format
+from narwhals._pandas_like.utils import get_dtype_backend
 from tests.utils import (
+    PANDAS_VERSION,
     PYARROW_VERSION,
     assert_equal_data,
     is_pyarrow_windows_no_tzdata,
@@ -231,3 +233,25 @@ def test_to_datetime_tz_aware(
             "b": [datetime(2020, 1, 1, 0, 2, 3, tzinfo=timezone.utc)],
         }
         assert_equal_data(result, expected)
+
+
+@pytest.mark.skipif(PANDAS_VERSION < (2, 2, 0), reason="too old for pyarrow types")
+def test_to_datetime_pd_preserves_pyarrow_backend_dtype() -> None:
+    # Remark that pandas doesn't have a numpy-nullable datetime dtype, so
+    # `.convert_dtypes(dtype_backend="numpy_nullable")` is a no-op in `_to_datetime(...)`
+    pytest.importorskip("pandas")
+    pytest.importorskip("pyarrow")
+    import pandas as pd
+
+    dtype_backend: Literal["pyarrow", "numpy_nullable"] = "pyarrow"
+
+    df = nw.from_native(
+        pd.DataFrame({"a": ["2020-01-01T12:34:56", None]}).convert_dtypes(
+            dtype_backend=dtype_backend
+        )
+    )
+    result = df.with_columns(b=nw.col("a").str.to_datetime()).to_native()
+    result_dtype = get_dtype_backend(
+        result["b"].dtype, df._compliant_frame._implementation
+    )
+    assert result_dtype == dtype_backend
