@@ -4,8 +4,7 @@ import pandas as pd
 import pytest
 
 import narwhals as nw
-from tests.utils import ConstructorEager
-from tests.utils import assert_equal_data
+from tests.utils import ConstructorEager, assert_equal_data
 
 
 def test_get_column(constructor_eager: ConstructorEager) -> None:
